@@ -27,8 +27,13 @@ trait EnsureSync: Sync {}
 pub trait ThreadSpawner {
     /// The return value from [`ThreadSpawner::spawn`]
     type SpawnReturn;
+    /// The error that can be returned
+    type SpawnError;
     /// Spawns a new thread running `function`
-    fn spawn(self, function: impl FnOnce() + 'static + Send) -> Self::SpawnReturn;
+    fn spawn(
+        self,
+        function: impl FnOnce() + 'static + Send,
+    ) -> Result<Self::SpawnReturn, Self::SpawnError>;
 }
 
 // TODO: Replace future associated types and boxed futures with existential types when stabilized https://rust-lang.github.io/rfcs/2071-impl-trait-existential-types.html
